fn answer_columns(answer: &SubmittedAnswer) -> ModelResult<AnswerColumns<'_>>Expand description
Splits a submitted answer into the columns it is stored in. The ids are assumed to be uploads the submitter is allowed to name; this does not check that.